pub enum CoopMatrixComponentType {
F16,
F32,
I8,
U8,
}Expand description
Scalar component types supported by cooperative-matrix operations.
Variants
F16
16-bit IEEE 754 half-precision float.
F32
32-bit IEEE 754 single-precision float.
I8
8-bit signed integer (used as accumulator in int8 GEMM paths).
U8
8-bit unsigned integer (used as input in int8 GEMM paths).
Implementations
Sourceimpl CoopMatrixComponentType
impl CoopMatrixComponentType
Sourcepub fn as_wgsl(self) -> &'static str
pub fn as_wgsl(self) -> &'static str
Return the corresponding WGSL type keyword.
Examples
use oxigdal_gpu::cooperative_matrix::CoopMatrixComponentType;
assert_eq!(CoopMatrixComponentType::F32.as_wgsl(), "f32");
assert_eq!(CoopMatrixComponentType::F16.as_wgsl(), "f16");Sourcepub fn byte_size(self) -> u32
pub fn byte_size(self) -> u32
Return the byte size of one element of this type.
Both I8 and U8 report 4 because WGSL maps them to i32/u32
in storage buffers (WGSL has no native 8-bit storage type).
Examples
use oxigdal_gpu::cooperative_matrix::CoopMatrixComponentType;
assert_eq!(CoopMatrixComponentType::F16.byte_size(), 2);
assert_eq!(CoopMatrixComponentType::F32.byte_size(), 4);Trait Implementations
Sourceimpl Clone for CoopMatrixComponentType
impl Clone for CoopMatrixComponentType
Sourcefn clone(&self) -> CoopMatrixComponentType
fn clone(&self) -> CoopMatrixComponentType
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CoopMatrixComponentType
Sourceimpl Debug for CoopMatrixComponentType
impl Debug for CoopMatrixComponentType
impl Eq for CoopMatrixComponentType
Sourceimpl PartialEq for CoopMatrixComponentType
impl PartialEq for CoopMatrixComponentType
Sourcefn eq(&self, other: &CoopMatrixComponentType) -> bool
fn eq(&self, other: &CoopMatrixComponentType) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CoopMatrixComponentType