pub struct RasterKernel { /* private fields */ }Expand description
GPU kernel for element-wise raster operations.
Implementations
Sourceimpl RasterKernel
impl RasterKernel
Sourcepub fn new(context: &GpuContext, op: ElementWiseOp) -> GpuResult<Self>
pub fn new(context: &GpuContext, op: ElementWiseOp) -> GpuResult<Self>
Create a new raster kernel for the specified operation.
Errors
Returns an error if shader compilation or pipeline creation fails.