GPU buffer management for OxiGDAL.
This module provides efficient GPU buffer management for raster data, including upload, download, and memory mapping operations.
Structs
- GpuBuffer
- GPU buffer wrapper with type safety.
- GpuRaster
Buffer - GPU raster buffer for multi-band raster data.
Enums
- Buffer
Element Type - Describes the scalar element type stored in a GPU buffer.
Functions
- f16_
to_ f32_ slice - Convert a slice of
half::f16values to aVec<f32>by widening. - f32_
to_ f16_ slice - Convert a slice of
f32values to aVec<half::f16>by narrowing. - from_
f16_ slice_ native - Upload a
half::f16slice to the GPU as raw bytes (u8buffer). - from_
f16_ slice_ widening - Upload a
half::f16slice to the GPU by widening each element tof32. - read_
f16_ from_ f32_ buffer - Read back a
GpuBuffer<f32>and narrow each element tohalf::f16.